Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(90)

Unified Diff: chrome/browser/chromeos/login/multi_profile_user_controller.h

Issue 117263002: Prevent ONC-pushed certificates from being used with multiprofiles. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Philipps suggestion, another test Created 7 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/chromeos/login/multi_profile_user_controller.h
diff --git a/chrome/browser/chromeos/login/multi_profile_user_controller.h b/chrome/browser/chromeos/login/multi_profile_user_controller.h
index 0e86e7ef7febb7af7d3c71b9a3eda761c4225809..4c1a907de65f363abba83c806e004eec91d19ba2 100644
--- a/chrome/browser/chromeos/login/multi_profile_user_controller.h
+++ b/chrome/browser/chromeos/login/multi_profile_user_controller.h
@@ -43,8 +43,8 @@ class MultiProfileUserController {
// Starts to observe the multiprofile user behavior pref of the given profile.
void StartObserving(Profile* user_profile);
- // Removes the cached value for the given user.
- void RemoveCachedValue(const std::string& user_email);
+ // Removes the cached values for the given user.
+ void RemoveCachedValues(const std::string& user_email);
// Possible behavior values.
static const char kBehaviorUnrestricted[];

Powered by Google App Engine
This is Rietveld 408576698